==> maruku-0.5.5.gem: tests/unittest/wrapping.md <==
Write a comment abouth the test here.
*** Parameters: ***
{}
*** Markdown input: ***
Lorem ipsum dolor amet. Lorem ipsum dolor amet. Lorem ipsum dolor amet. Lorem ipsum dolor amet. Lorem ipsum dolor amet. Lorem ipsum dolor amet. Lorem ipsum dolor amet. Break:  
Lorem ipsum dolor amet. Lorem ipsum dolor amet. Lorem ipsum dolor amet. Lorem ipsum dolor amet. 

* Lorem ipsum dolor amet. Lorem ipsum dolor amet. Lorem ipsum dolor amet. Lorem ipsum dolor amet
  Lorem ipsum Break:  
  Lorem ipsum dolor amet. Lorem ipsum dolor amet. Lorem ipsum dolor amet
* Lorem ipsum dolor amet. Lorem ipsum dolor amet. Lorem ipsum dolor amet. Lorem ipsum dolor amet

*** Output of inspect ***
md_el(:document,[
	md_par([
		"Lorem ipsum dolor amet. Lorem ipsum dolor amet. Lorem ipsum dolor amet. Lorem ipsum dolor amet. Lorem ipsum dolor amet. Lorem ipsum dolor amet. Lorem ipsum dolor amet. Break:",
		md_el(:linebreak,[],{},[]),
		"Lorem ipsum dolor amet. Lorem ipsum dolor amet. Lorem ipsum dolor amet. Lorem ipsum dolor amet."
	]),
	md_el(:ul,[
		md_el(:li_span,[
			"Lorem ipsum dolor amet. Lorem ipsum dolor amet. Lorem ipsum dolor amet. Lorem ipsum dolor amet Lorem ipsum Break:",
			md_el(:linebreak,[],{},[]),
			"Lorem ipsum dolor amet. Lorem ipsum dolor amet. Lorem ipsum dolor amet"
		],{:want_my_paragraph=>false},[]),
		md_el(:li_span,[
			"Lorem ipsum dolor amet. Lorem ipsum dolor amet. Lorem ipsum dolor amet. Lorem ipsum dolor amet"
		],{:want_my_paragraph=>false},[])
	],{},[])
],{},[])
*** Output of to_html ***

<p>Lorem ipsum dolor amet. Lorem ipsum dolor amet. Lorem ipsum dolor amet. Lorem ipsum dolor amet. Lorem ipsum dolor amet. Lorem ipsum dolor amet. Lorem ipsum dolor amet. Break:<br />Lorem ipsum dolor amet. Lorem ipsum dolor amet. Lorem ipsum dolor amet. Lorem ipsum dolor amet.</p>

<ul>
<li>Lorem ipsum dolor amet. Lorem ipsum dolor amet. Lorem ipsum dolor amet. Lorem ipsum dolor amet Lorem ipsum Break:<br />Lorem ipsum dolor amet. Lorem ipsum dolor amet. Lorem ipsum dolor amet</li>

<li>Lorem ipsum dolor amet. Lorem ipsum dolor amet. Lorem ipsum dolor amet. Lorem ipsum dolor amet</li>
</ul>

*** Output of to_latex ***
Lorem ipsum dolor amet. Lorem ipsum dolor amet. Lorem ipsum dolor amet. Lorem ipsum dolor amet. Lorem ipsum dolor amet. Lorem ipsum dolor amet. Lorem ipsum dolor amet. Break:\linebreak Lorem ipsum dolor amet. Lorem ipsum dolor amet. Lorem ipsum dolor amet. Lorem ipsum dolor amet.

\begin{itemize}%
\item Lorem ipsum dolor amet. Lorem ipsum dolor amet. Lorem ipsum dolor amet. Lorem ipsum dolor amet Lorem ipsum Break:\linebreak Lorem ipsum dolor amet. Lorem ipsum dolor amet. Lorem ipsum dolor amet
\item Lorem ipsum dolor amet. Lorem ipsum dolor amet. Lorem ipsum dolor amet. Lorem ipsum dolor amet

\end{itemize}

*** Output of to_md ***
Lorem ipsum dolor amet. Lorem ipsum
dolor amet. Lorem ipsum dolor amet.
Lorem ipsum dolor amet. Lorem ipsum
dolor amet. Lorem ipsum dolor amet.
Lorem ipsum dolor amet. Break:  
Lorem ipsum dolor amet. Lorem ipsum
dolor amet. Lorem ipsum dolor amet.
Lorem ipsum dolor amet.

-orem ipsum dolor amet. Lorem ipsum
dolor amet. Lorem ipsum dolor amet.
Lorem ipsum dolor amet Lorem ipsum
Break:  
Lorem ipsum dolor amet. Lorem ipsum
dolor amet. Lorem ipsum dolor amet
-orem ipsum dolor amet. Lorem ipsum
dolor amet. Lorem ipsum dolor amet.
Lorem ipsum dolor amet


*** Output of to_s ***
Lorem ipsum dolor amet. Lorem ipsum dolor amet. Lorem ipsum dolor amet. Lorem ipsum dolor amet. Lorem ipsum dolor amet. Lorem ipsum dolor amet. Lorem ipsum dolor amet. Break:Lorem ipsum dolor amet. Lorem ipsum dolor amet. Lorem ipsum dolor amet. Lorem ipsum dolor amet.Lorem ipsum dolor amet. Lorem ipsum dolor amet. Lorem ipsum dolor amet. Lorem ipsum dolor amet Lorem ipsum Break:Lorem ipsum dolor amet. Lorem ipsum dolor amet. Lorem ipsum dolor ametLorem ipsum dolor amet. Lorem ipsum dolor amet. Lorem ipsum dolor amet. Lorem ipsum dolor amet
*** EOF ***



	OK!



*** Output of Markdown.pl ***
<p>Lorem ipsum dolor amet. Lorem ipsum dolor amet. Lorem ipsum dolor amet. Lorem ipsum dolor amet. Lorem ipsum dolor amet. Lorem ipsum dolor amet. Lorem ipsum dolor amet. Break: <br />
Lorem ipsum dolor amet. Lorem ipsum dolor amet. Lorem ipsum dolor amet. Lorem ipsum dolor amet. </p>

<ul>
<li>Lorem ipsum dolor amet. Lorem ipsum dolor amet. Lorem ipsum dolor amet. Lorem ipsum dolor amet
Lorem ipsum Break: <br />
Lorem ipsum dolor amet. Lorem ipsum dolor amet. Lorem ipsum dolor amet</li>
<li>Lorem ipsum dolor amet. Lorem ipsum dolor amet. Lorem ipsum dolor amet. Lorem ipsum dolor amet</li>
</ul>

*** Output of Markdown.pl (parsed) ***
<p>Lorem ipsum dolor amet. Lorem ipsum dolor amet. Lorem ipsum dolor amet. Lorem ipsum dolor amet. Lorem ipsum dolor amet. Lorem ipsum dolor amet. Lorem ipsum dolor amet. Break: <br/
     >
Lorem ipsum dolor amet. Lorem ipsum dolor amet. Lorem ipsum dolor amet. Lorem ipsum dolor amet. </p
   ><ul>
<li>Lorem ipsum dolor amet. Lorem ipsum dolor amet. Lorem ipsum dolor amet. Lorem ipsum dolor amet
Lorem ipsum Break: <br/
       >
Lorem ipsum dolor amet. Lorem ipsum dolor amet. Lorem ipsum dolor amet</li
     >
<li>Lorem ipsum dolor amet. Lorem ipsum dolor amet. Lorem ipsum dolor amet. Lorem ipsum dolor amet</li
     >
</ul
 >

==> maruku-0.5.6.gem: tests/unittest/wrapping.md <==
Write a comment abouth the test here.
*** Parameters: ***
{}
*** Markdown input: ***
Lorem ipsum dolor amet. Lorem ipsum dolor amet. Lorem ipsum dolor amet. Lorem ipsum dolor amet. Lorem ipsum dolor amet. Lorem ipsum dolor amet. Lorem ipsum dolor amet. Break:  
Lorem ipsum dolor amet. Lorem ipsum dolor amet. Lorem ipsum dolor amet. Lorem ipsum dolor amet. 

* Lorem ipsum dolor amet. Lorem ipsum dolor amet. Lorem ipsum dolor amet. Lorem ipsum dolor amet
  Lorem ipsum Break:  
  Lorem ipsum dolor amet. Lorem ipsum dolor amet. Lorem ipsum dolor amet
* Lorem ipsum dolor amet. Lorem ipsum dolor amet. Lorem ipsum dolor amet. Lorem ipsum dolor amet

*** Output of inspect ***
md_el(:document,[
	md_par([
		"Lorem ipsum dolor amet. Lorem ipsum dolor amet. Lorem ipsum dolor amet. Lorem ipsum dolor amet. Lorem ipsum dolor amet. Lorem ipsum dolor amet. Lorem ipsum dolor amet. Break:",
		md_el(:linebreak,[],{},[]),
		"Lorem ipsum dolor amet. Lorem ipsum dolor amet. Lorem ipsum dolor amet. Lorem ipsum dolor amet."
	]),
	md_el(:ul,[
		md_el(:li_span,[
			"Lorem ipsum dolor amet. Lorem ipsum dolor amet. Lorem ipsum dolor amet. Lorem ipsum dolor amet Lorem ipsum Break:",
			md_el(:linebreak,[],{},[]),
			"Lorem ipsum dolor amet. Lorem ipsum dolor amet. Lorem ipsum dolor amet"
		],{:want_my_paragraph=>false},[]),
		md_el(:li_span,[
			"Lorem ipsum dolor amet. Lorem ipsum dolor amet. Lorem ipsum dolor amet. Lorem ipsum dolor amet"
		],{:want_my_paragraph=>false},[])
	],{},[])
],{},[])
*** Output of to_html ***

<p>Lorem ipsum dolor amet. Lorem ipsum dolor amet. Lorem ipsum dolor amet. Lorem ipsum dolor amet. Lorem ipsum dolor amet. Lorem ipsum dolor amet. Lorem ipsum dolor amet. Break:<br />Lorem ipsum dolor amet. Lorem ipsum dolor amet. Lorem ipsum dolor amet. Lorem ipsum dolor amet.</p>

<ul>
<li>Lorem ipsum dolor amet. Lorem ipsum dolor amet. Lorem ipsum dolor amet. Lorem ipsum dolor amet Lorem ipsum Break:<br />Lorem ipsum dolor amet. Lorem ipsum dolor amet. Lorem ipsum dolor amet</li>

<li>Lorem ipsum dolor amet. Lorem ipsum dolor amet. Lorem ipsum dolor amet. Lorem ipsum dolor amet</li>
</ul>

*** Output of to_latex ***
Lorem ipsum dolor amet. Lorem ipsum dolor amet. Lorem ipsum dolor amet. Lorem ipsum dolor amet. Lorem ipsum dolor amet. Lorem ipsum dolor amet. Lorem ipsum dolor amet. Break:\newline Lorem ipsum dolor amet. Lorem ipsum dolor amet. Lorem ipsum dolor amet. Lorem ipsum dolor amet.

\begin{itemize}%
\item Lorem ipsum dolor amet. Lorem ipsum dolor amet. Lorem ipsum dolor amet. Lorem ipsum dolor amet Lorem ipsum Break:\newline Lorem ipsum dolor amet. Lorem ipsum dolor amet. Lorem ipsum dolor amet
\item Lorem ipsum dolor amet. Lorem ipsum dolor amet. Lorem ipsum dolor amet. Lorem ipsum dolor amet

\end{itemize}

*** Output of to_md ***
Lorem ipsum dolor amet. Lorem ipsum
dolor amet. Lorem ipsum dolor amet.
Lorem ipsum dolor amet. Lorem ipsum
dolor amet. Lorem ipsum dolor amet.
Lorem ipsum dolor amet. Break:  
Lorem ipsum dolor amet. Lorem ipsum
dolor amet. Lorem ipsum dolor amet.
Lorem ipsum dolor amet.

-orem ipsum dolor amet. Lorem ipsum
dolor amet. Lorem ipsum dolor amet.
Lorem ipsum dolor amet Lorem ipsum
Break:  
Lorem ipsum dolor amet. Lorem ipsum
dolor amet. Lorem ipsum dolor amet
-orem ipsum dolor amet. Lorem ipsum
dolor amet. Lorem ipsum dolor amet.
Lorem ipsum dolor amet


*** Output of to_s ***
Lorem ipsum dolor amet. Lorem ipsum dolor amet. Lorem ipsum dolor amet. Lorem ipsum dolor amet. Lorem ipsum dolor amet. Lorem ipsum dolor amet. Lorem ipsum dolor amet. Break:Lorem ipsum dolor amet. Lorem ipsum dolor amet. Lorem ipsum dolor amet. Lorem ipsum dolor amet.Lorem ipsum dolor amet. Lorem ipsum dolor amet. Lorem ipsum dolor amet. Lorem ipsum dolor amet Lorem ipsum Break:Lorem ipsum dolor amet. Lorem ipsum dolor amet. Lorem ipsum dolor ametLorem ipsum dolor amet. Lorem ipsum dolor amet. Lorem ipsum dolor amet. Lorem ipsum dolor amet
*** EOF ***



	OK!



*** Output of Markdown.pl ***
<p>Lorem ipsum dolor amet. Lorem ipsum dolor amet. Lorem ipsum dolor amet. Lorem ipsum dolor amet. Lorem ipsum dolor amet. Lorem ipsum dolor amet. Lorem ipsum dolor amet. Break: <br />
Lorem ipsum dolor amet. Lorem ipsum dolor amet. Lorem ipsum dolor amet. Lorem ipsum dolor amet. </p>

<ul>
<li>Lorem ipsum dolor amet. Lorem ipsum dolor amet. Lorem ipsum dolor amet. Lorem ipsum dolor amet
Lorem ipsum Break: <br />
Lorem ipsum dolor amet. Lorem ipsum dolor amet. Lorem ipsum dolor amet</li>
<li>Lorem ipsum dolor amet. Lorem ipsum dolor amet. Lorem ipsum dolor amet. Lorem ipsum dolor amet</li>
</ul>

*** Output of Markdown.pl (parsed) ***
<p>Lorem ipsum dolor amet. Lorem ipsum dolor amet. Lorem ipsum dolor amet. Lorem ipsum dolor amet. Lorem ipsum dolor amet. Lorem ipsum dolor amet. Lorem ipsum dolor amet. Break: <br/
     >
Lorem ipsum dolor amet. Lorem ipsum dolor amet. Lorem ipsum dolor amet. Lorem ipsum dolor amet. </p
   ><ul>
<li>Lorem ipsum dolor amet. Lorem ipsum dolor amet. Lorem ipsum dolor amet. Lorem ipsum dolor amet
Lorem ipsum Break: <br/
       >
Lorem ipsum dolor amet. Lorem ipsum dolor amet. Lorem ipsum dolor amet</li
     >
<li>Lorem ipsum dolor amet. Lorem ipsum dolor amet. Lorem ipsum dolor amet. Lorem ipsum dolor amet</li
     >
</ul
 >
